@@ -205,7 +205,7 @@ dot.Graph = class {
 
 dot.Argument = class {
 
-    constructor(name, value, type) {
+    constructor(name, value, type = null) {
         this.name = name;
         this.value = value;
         this.type = type;
