@@ -29,7 +29,7 @@ zip.Archive = class {
                     return new zlib.Archive(stream);
                 }
             }
-            if ((!format || format === 'gzip') && buffer.length > 18 && buffer[0] === 0x1f && buffer[1] === 0x8b) { // gzip
+            if ((!format || format === 'gzip') && buffer.length >= 18 && buffer[0] === 0x1f && buffer[1] === 0x8b) { // gzip
                 return new gzip.Archive(stream);
             }
             if (!format || format === 'zip') {
@@ -58,7 +58,7 @@ zip.Archive = class {
                     return null;
                 };
                 const read = (signature, size) => {
-                    if ((stream.position - size) > 0) {
+                    if ((stream.position - size) >= 0) {
                         stream.skip(-size);
                         signature = Array.from(signature, (c) => c.charCodeAt(0));
                         const buffer = stream.peek(size);
